Test store*

Test store and variations
open | ../tests/html/test_verifications.html |
storeValue | theHidden | storedHiddenValue
storeText | theSpan | storedSpanText
storeAttribute | theText@class | storedTextClass
storeTitle | storedTitle |
store | PLAIN TEXT | textVariable
store | javascript{'Pi ~= ' + (Math.round(Math.PI * 100) / 100)} | javascriptVariable
open | ../tests/html/test_store_value.html |
type | theText | ${storedHiddenValue}
verifyValue | theText | the hidden value
type | theText | ${storedSpanText}
verifyValue | theText | this is the span
type | theText | ${storedTextClass}
verifyValue | theText | foo
type | theText | ${textVariable}
verifyValue | theText | PLAIN TEXT
type | theText | ${javascriptVariable}
verifyValue | theText | Pi ~= 3.14
type | theText | ${storedTitle}
verifyValue | theText | theTitle
type | theText | '${storedHiddenValue}'_'${storedSpanText}'
verifyValue | theText | 'the hidden value'_'this is the span'
open | ../tests/html/test_just_text.html |
storeBodyText | storedBodyText |
open | ../tests/html/test_store_value.html |
verifyValue | theText |
type | theText | ${storedBodyText}
verifyValue | theText | This is the entire text of the page.
verifyExpression | ${storedBodyText} | This is the entire text of the page.